@@ -1,17 +1,12 @@
-lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = NULL, stopping = "BIC", tol = 2, heavy = FALSE, robust = FALSE, ncores = 1 ) {
+lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = NULL, stopping = "BIC", tol = 2, robust = FALSE, ncores = 1 ) {
   
   threshold = log(threshold)
-  
   p <- dim(dataset)[2]  ## number of variables
   pval <- stat <- dof <- numeric( p )  
   moda <- list()
-  
   ## percentages
-  if ( min( target ) > 0  &  max( target ) < 1 )  {  ## are they percentages?
-    target <- log( target / (1 - target) ) 
-  }
-  
-    #check for NA values in the dataset and replace them with the variable median or the mode
+  if ( min( target ) > 0  &  max( target ) < 1 )   target <- log( target / (1 - target) ) 
+  #check for NA values in the dataset and replace them with the variable median or the mode
   if( any(is.na(dataset)) ) {
     #dataset = as.matrix(dataset);
     warning("The dataset contains missing values (NA) and they were replaced automatically by the variable (column) median (for numeric) or by the most frequent level (mode) if the variable is factor")
@@ -24,15 +19,12 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
         if(class(xi) == "numeric")
         {                    
           xi[ which( is.na(xi) ) ] <- median(xi, na.rm = TRUE) 
-        } else if ( is.factor( xi ) ) {
-          xi[ which( is.na(xi) ) ] <- levels(xi)[ which.max( as.vector( table(xi) ) )]
-        }
+        } else if ( is.factor( xi ) )   xi[ which( is.na(xi) ) ] <- levels(xi)[ which.max( as.vector( table(xi) ) )]
         dataset[, i] <- xi
       }
     }
   }
   
-  
   ## is there already an initial set of variables to start with?
   if ( is.null(iniset) ) {
     da <- 0
@@ -43,7 +35,6 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
     da <- 1:pa
     dataset <- cbind(iniset, dataset)
   }  
-
   
   n <- length(target)  ## sample size
   con <- log(n)
@@ -57,8 +48,6 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
   if (ncores <= 1) {
     
     if ( !robust ) {  ## Non robust
-	
-	  if ( !heavy ) {
 	    ci_test <- "testsIndReg"
         for (i in 1:p) {
           ww <- lm( target ~., data = as.data.frame( dataset[, c(da, pa + i)] ), weights = wei, y = FALSE, model = FALSE )
@@ -67,32 +56,14 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
           df1 <- tab[pa + k, 1]   ;  df2 = tab[pa + k + 1, 1]
           pval[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
         } 
-		
-	  } else {
-	    ci_test <- "testIndSpeedglm"
-	  	fit1 <- speedglm::speedlm( target ~., data = as.data.frame(iniset), weights = wei )
-		  fit1rss <- fit1$RSS 
-      d1 <- length( coef(fit1) )
-		  for (i in 1:pn) {
-          fit2 <- speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, pa + i)] ), weights= wei )
-          d2 <- length( coef(fit2) )
-          df1 <- d2 - d1
-          df2 <- n - d2
-          stat[i] <- (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
-          pval[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
-        } 	
-	  
-	  }	
       mat <- cbind(1:p, pval, stat)
       
     } else {  ## Robust
-      
       for (i in 1:p) {
         ww <- MASS::rlm( target ~., data = as.data.frame( dataset[, c(da, pa + i)] ), maxit = 2000, weights = wei ) 
         stat[i] <- 2 * as.numeric( logLik(ww) )
         dof[i] <- length( coef(ww) )
       }
-	  
       fit0 <- MASS::rlm( target ~ ., data = as.data.frame(iniset), maxit = 2000, weights = wei ) 
       stat0 <- 2 * as.numeric( logLik(fit0) )
       difa <- abs( stat - stat0 )
@@ -103,8 +74,6 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
   } else {
     
     if ( !robust ) {  ## Non robust
-	
-	  if ( !heavy ) {
         cl <- makePSOCKcluster(ncores)
         registerDoParallel(cl)
         mat <- matrix(0, p, 2)
@@ -116,34 +85,12 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
           pval[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
           mat[i, ] <- c(pval[i], stat[i]) 
         }
-		
         stopCluster(cl)
-		
-	  } else {
-        cl <- makePSOCKcluster(ncores)
-        registerDoParallel(cl)
-	      fit1 <- speedglm::speedlm( target ~., data = as.data.frame(iniset), weights = wei )
-		    fit1rss <- fit1$RSS 
-        d1 <- length( coef(fit1) )
-        mat <- matrix(0, p, 2)
-        mod <- foreach( i = 1:p, .combine = rbind, .export = "speedlm", .packages = "speedglm" ) %dopar% {
-          fit2 <- speedlm( target ~., data = as.data.frame( dataset[, c(da, pa + i)] ), weights = wei )
-          d2 <- length( coef(fit2) )
-          df1 <- d2 - d1
-          df2 <- n - d2
-          stat[i] <- (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
-          pval[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
-          mat[i, ] <- c(pval[i], stat[i]) 
-        }
-		
-        stopCluster(cl)	 	  
-	  }
 	       
     } else {  ## Robust
       
       fit0 = MASS::rlm( target ~., data = as.data.frame(iniset), maxit = 2000, weights = wei ) 
       stat0 = 2 * logLik(fit0)
-      
       cl <- makePSOCKcluster(ncores)
       registerDoParallel(cl)
       mat <- matrix(0, p, 2)
@@ -159,7 +106,6 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
     }
     
     mat <- cbind(1:p, mod)      
-    
   }
   
   colnames(mat) <- c( "variables", "log.p-value", "stat" )
@@ -176,14 +122,8 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
     if ( stopping == "adjrsq" ) {
       
       if ( !robust ) {
-	  
-	    if ( !heavy ) {
-          mi = lm( target ~., data = as.data.frame( dataset[, c(da, sel) ] ), weights = wei, y = FALSE, model = FALSE )
-          tool[k] <- as.numeric( summary( mi )[[ 9 ]] )
-		} else {
-		  mi = speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sel) ] ), weights = wei )
-          tool[k] <- as.numeric( summary( mi )[[ 11 ]] )
-		}
+        mi = lm( target ~., data = as.data.frame( dataset[, c(da, sel) ] ), weights = wei, y = FALSE, model = FALSE )
+        tool[k] <- as.numeric( summary( mi )[[ 9 ]] )
 		
       } else {
         mi = MASS::rlm( target ~., data = as.data.frame( dataset[, c(da, sel) ] ), maxit = 2000, weights = wei )
@@ -193,14 +133,8 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
       
     } else if ( stopping  == "BIC" ) { 
       if ( !robust ) {
-	    if ( !heavy ) {
-          mi = lm( target ~., data = as.data.frame( dataset[, c(da, sel) ] ), y = FALSE, model = FALSE )
-          tool[k] <- BIC( mi )
-		} else {
-          mi = speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sel) ] ), weights = wei )
-          tool[k] <-  - 2 * logLik(mi) + length( coef(mi) ) * con 
-	   	}
-		
+        mi = lm( target ~., data = as.data.frame( dataset[, c(da, sel) ] ), y = FALSE, model = FALSE )
+        tool[k] <- BIC( mi )
       } else {
         mi = MASS::rlm( target ~., data=as.data.frame( dataset[, c(da, sel) ] ), maxit = 2000, weights = wei )
         tool[k] <-  BIC(mi)
@@ -209,12 +143,9 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
     moda[[ k ]] <- mi
     
   }
-  
-  
   ######
   ###### k equal to 2
   ######
-  
   if ( info[k, 2] < threshold  &  nrow(mat) > 0 ) {
     
     k <- k + 1
@@ -223,29 +154,14 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
     if ( ncores <= 1 ) {
 	
       if ( !robust ) { 
-	  
-        if ( !heavy ) {
-          for (i in 1:pn) {
-            ww = lm( target ~., data = as.data.frame( dataset[, c(da, sel, mat[pa + i, 1]) ] ), weights = wei, y = FALSE, model = FALSE )
-            tab = anova( ww )
-            mat[i, 3] = tab[pa + k, 4] 
-            df1 = tab[pa + k, 1]   ;  df2 = tab[pa + k + 1, 1]
-            mat[i, 2] = pf( mat[i, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-          }
-		  
-        } else {
-		      fit1rss <- mi$RSS 
-          d1 <- length( coef(fit1) )
-		      for (i in 1:pn) {
-            fit2 = speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sel, mat[pa + i, 1]) ] ), weights= wei )
-            d2 = length( coef(fit2) )
-            df1 = d2 - d1
-            df2 = n - d2
-            mat[i, 3] = (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
-            mat[i, 2] = pf( mat[i, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-		     }	  
-		   }
-		
+         for (i in 1:pn) {
+           ww = lm( target ~., data = as.data.frame( dataset[, c(da, sel, mat[pa + i, 1]) ] ), weights = wei, y = FALSE, model = FALSE )
+           tab = anova( ww )
+           mat[i, 3] = tab[pa + k, 4] 
+           df1 = tab[pa + k, 1]   ;  df2 = tab[pa + k + 1, 1]
+           mat[i, 2] = pf( mat[i, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
+         }
+
      } else {
         do = 2 * as.numeric( logLik( mi ) )
         fr = length( coef( mi ) )
@@ -263,44 +179,23 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
     } else {
       
       if ( !robust ) {  ## Non robust
-	  
-	    if ( !heavy ) {
-          cl <- makePSOCKcluster(ncores)
-          registerDoParallel(cl)
-          stat <- pval <- numeric(pn) 
-          mata <- matrix(0, pn, 2)
-          mod <- foreach( i = 1:pn, .combine = rbind) %dopar% {
-            ww <- lm( target ~., data = as.data.frame( dataset[, c(da, sel, mat[pa + i, 1]) ] ), weights = wei, y = FALSE, model = FALSE )
-            tab <- anova( ww )
-            stat[i] <- tab[pa + k, 4] 
-            df1 <- tab[pa + k, 1]   ;  df2 = tab[pa + k + 1, 1]
-            pval[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
-            mata[i, ] <- c(pval[i], stat[i]) 
+        cl <- makePSOCKcluster(ncores)
+        registerDoParallel(cl)
+        stat <- pval <- numeric(pn) 
+        mata <- matrix(0, pn, 2)
+        mod <- foreach( i = 1:pn, .combine = rbind) %dopar% {
+          ww <- lm( target ~., data = as.data.frame( dataset[, c(da, sel, mat[pa + i, 1]) ] ), weights = wei, y = FALSE, model = FALSE )
+          tab <- anova( ww )
+          stat[i] <- tab[pa + k, 4] 
+          df1 <- tab[pa + k, 1]   ;  df2 = tab[pa + k + 1, 1]
+          pval[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
+          mata[i, ] <- c(pval[i], stat[i]) 
         }
-          stopCluster(cl)
-		  
-        } else {
-		  cl <- makePSOCKcluster(ncores)
-          registerDoParallel(cl)
-          fit1rss <- mi$RSS 
-          stat <- pval <- numeric(pn) 
-          mata <- matrix(0, pn, 2)
-          mod <- foreach( i = 1:pn, .combine = rbind, .export = "speedlm", .packages = "speedglm") %dopar% {
-            fit2 <- speedlm( target ~., data = as.data.frame( dataset[, c(da, sel, mat[pa + i, 1]) ] ), weights = wei )
-            d2 <- length( coef(fit2) )
-            df1 <- d2 - d1
-            df2 <- n - d2
-            stat[i] <- (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
-            pval[i] <- pf( mat[i, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-            mata[i, ] <- c( pval[i], stat[i] ) 
-          }
-          stopCluster(cl)
-		   }
-		
+        stopCluster(cl)
+
       } else {  ## Robust
         do <- 2 * as.numeric( logLik( mi ) )
         fr <- length( coef( mi ) )
-        
         cl <- makePSOCKcluster(ncores)
         registerDoParallel(cl)
         mata <- matrix(0, pn, 2)
@@ -309,7 +204,6 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
           mata[i, ] <- c( 2 * as.numeric( logLik(ww) ), length( coef(ww) ) )
         }
         stopCluster(cl)
-        
         difa <- abs( mod[, 1] - do )
         pval <- pchisq(difa, mod[, 2] - fr, lower.tail = FALSE, log.p = TRUE)
         mod <- cbind( pval, difa)
@@ -317,7 +211,6 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
       mat <- cbind(mat[, 1], mod)   
       
     }
-    
   }
   
   ina <- which.min(mat[, 2])
@@ -327,14 +220,9 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
   
     if ( mat[ina, 2] < threshold ) {
       if ( !robust ) {
-	      if ( !heavy ) {
-          ma <- lm( target ~., data=as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei, y = FALSE, model = FALSE )
-          tool[k] <- as.numeric( summary( ma )[[ 9 ]] )
-		    } else {
-          ma <- speedglm::speedlm( target ~., data=as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei, y = FALSE, model = FALSE )
-          tool[k] <- as.numeric( summary( ma )[[ 11 ]] )		
-		    }
-		
+        ma <- lm( target ~., data=as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei, y = FALSE, model = FALSE )
+        tool[k] <- as.numeric( summary( ma )[[ 9 ]] )
+        
       } else {        
         ma <- MASS::rlm( target ~., data=as.data.frame( dataset[, c(da, sela, sel) ] ), maxit = 2000, weights = wei )
         r2 <- cor( target, fitted(ma) )^2
@@ -358,20 +246,15 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
   
     if ( mat[ina, 2] < threshold ) {
       if ( !robust ) {            
-	      if ( !heavy ) {
-          ma <- lm( target ~., data = as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei, y = FALSE, model = FALSE )
-          tool[k] <- BIC( ma )
-		    } else {
-          ma <- speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei )
-          tool[k] <-  - 2 * logLik(ma) + length( coef(ma ) ) * con
-	    	}
-		
+         ma <- lm( target ~., data = as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei, y = FALSE, model = FALSE )
+         tool[k] <- BIC( ma )
+
       } else {
         ma <- MASS::rlm(target ~ target ~., data = as.data.frame( dataset[, c(da, sela, sel) ] ), maxit = 2000, weights = wei )
         tool[k] <- BIC(ma)
       }
       if ( tool[ k - 1] - tool[ k ] <= tol ) {
-        info <- rbind(info, c( 1e300, 0, 0 ) )
+        info <- info
         
       } else {  
         info <- rbind(info, mat[ina, ] )
@@ -383,14 +266,9 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
     } else  info <- info
     
   }
-  
-
-  
   ###########
   ######   k greater than 2
   ###########
-  
-  
   if ( nrow(info) > 1  &  nrow(mat) > 0 ) {
     
     while ( ( info[k, 2] < threshold ) &  ( k < n ) & ( abs( tool[ k ] - tool[ k - 1 ] ) > tol ) & ( nrow(mat) > 0 ) )  {
@@ -401,35 +279,19 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
       if ( ncores <= 1 ) {
 	  
         if ( !robust ) {
-		
-		  if ( !heavy ) {
-            for ( i in 1:pn ) {
-              ww <- lm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1]) ] ), weights = wei, y = FALSE, model = FALSE )
-              tab <- anova( ww )
-              mat[i, 3] <- tab[pa + k, 4] 
-              df1 <- tab[pa + k, 1]   ;  df2 = tab[pa + k + 1, 1]
-              mat[i, 2] <- pf( mat[i, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-            }
-			
-          } else {
-		    fit1rss <- ma$RSS 
-            d1 <- length( coef(fit1) )
-		    for (i in 1:pn) {
-              fit2 = speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sel, mat[pa + i, 1]) ] ), weights= wei )
-              d2 = length( coef(fit2) )
-              df1 = d2 - d1
-              df2 = n - d2
-              mat[i, 3] = (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
-              mat[i, 2] = pf( mat[i, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-		    }			  
-		  }
-		  
+          for ( i in 1:pn ) {
+            ww <- lm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1]) ] ), weights = wei, y = FALSE, model = FALSE )
+            tab <- anova( ww )
+            mat[i, 3] <- tab[pa + k, 4] 
+            df1 <- tab[pa + k, 1]   ;  df2 = tab[pa + k + 1, 1]
+            mat[i, 2] <- pf( mat[i, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
+          }
+
         } else {
           
           do = 2 * as.numeric( logLik( moda[[ k - 1 ]] ) )
           fr = length( coef( moda[[ k - 1 ]] ) )
           sta = dof = numeric(pn)
-          
           for (i in 1:pn) {
             ww = MASS::rlm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1]) ] ), maxit = 2000, weights = wei )
             sta[i] = 2 * as.numeric( logLik(ww) )
@@ -441,44 +303,23 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
         
       } else {
         if ( !robust ) {  ## Non robust
-		
-		  if ( !heavy ) {
-            cl <- makePSOCKcluster(ncores)
-            registerDoParallel(cl)
-            stat <- pval <- numeric(pn)
-            mata <- matrix(0, pn, 2)
-            mod <- foreach( i = 1:pn, .combine = rbind) %dopar% {
-              ww <- lm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1]) ] ), weights = wei, y = FALSE, model = FALSE )
-              tab <- anova(ww)
-              stat[i] <- tab[pa + k, 4] 
-              df1 <- tab[pa + k, 1]   ;  df2 = tab[pa + k + 1, 1]
-              pval[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
-              mata[i, ] <- c( pval[i], stat[i] ) 
-            }
-            stopCluster(cl)
-		  
-		  } else {
-		    cl <- makePSOCKcluster(ncores)
-            registerDoParallel(cl)
-            fit1rss <- ma$RSS 
-            stat <- pval <- numeric(pn) 
-            mata <- matrix(0, pn, 2)
-            mod <- foreach( i = 1:pn, .combine = rbind, .export = "speedlm", .packages = "speedglm") %dopar% {
-              fit2 <- speedlm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1]) ] ), weights = wei )
-              d2 = length( coef(fit2) )
-              df1 = d2 - d1
-              df2 = n - d2
-              stat[i] = (fit1rss - fit2$RSS)/df1 / ( fit2$RSS /df2 )
-              pval[i] = pf( mat[i, 3], df1, df2, lower.tail = FALSE, log.p = TRUE )
-              mata[i, ] <- c( pval[i], stat[i] ) 
-            }
-            stopCluster(cl)
-		  }
+          cl <- makePSOCKcluster(ncores)
+          registerDoParallel(cl)
+          stat <- pval <- numeric(pn)
+          mata <- matrix(0, pn, 2)
+          mod <- foreach( i = 1:pn, .combine = rbind) %dopar% {
+            ww <- lm( target ~., data = as.data.frame( dataset[, c(da, sela, mat[pa + i, 1]) ] ), weights = wei, y = FALSE, model = FALSE )
+            tab <- anova(ww)
+            stat[i] <- tab[pa + k, 4] 
+            df1 <- tab[pa + k, 1]   ;  df2 = tab[pa + k + 1, 1]
+            pval[i] <- pf( stat[i], df1, df2, lower.tail = FALSE, log.p = TRUE )
+            mata[i, ] <- c( pval[i], stat[i] ) 
+          }
+          stopCluster(cl)
           
        } else {  ## Robust
           do = 2 * as.numeric( logLik( ma) )
           fr = length( coef( ma ) )
-          
           cl <- makePSOCKcluster(ncores)
           registerDoParallel(cl)
           mata <- matrix(0, pn, 2)
@@ -491,9 +332,7 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
           pval = pchisq(difa, mod[, 2] - fr, lower.tail = FALSE, log.p = TRUE)
           mod = cbind( pval, difa)
         }
-        
         mat <- cbind( mat[, 1], mod )   
-        
       }
       
       ina <- which.min(mat[, 2])
@@ -504,13 +343,8 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
         if ( mat[ina, 2] < threshold ) {
 		
           if ( !robust ) {
-		    if ( !heavy ){
-              ma <- lm( target ~., data = as.data.frame( dataset[, c(da, sela, sel)] ), weights = wei, y = FALSE, model = FALSE )
-              tool[k] <- BIC( ma )
-			} else {
-              ma <- speedglm::speedlm( target ~., data = as.data.frame( dataset[, c(da, sela, sel)] ), weights = wei )
-              tool[k] <-  - 2 * logLik(ma) + length( coef(ma ) ) * con		
-			}  
+            ma <- lm( target ~., data = as.data.frame( dataset[, c(da, sela, sel)] ), weights = wei, y = FALSE, model = FALSE )
+            tool[k] <- BIC( ma )
 			
           } else {
             ma <- MASS::rlm( target ~., data = as.data.frame( dataset[, c(da, sela, sel)] ), maxit = 2000, weights = wei )
@@ -534,14 +368,9 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
 	    if ( mat[ina, 2] < threshold ) {
           
         if ( !robust ) {
-		      if ( !heavy ) {
-            ma <- lm( target ~., data = as.data.frame( dataset[, c(da, sela, sel)] ), weights = wei, y = FALSE, model = FALSE )
-            tool[k] <- as.numeric( summary(ma)[[ 9 ]] )
-			    } else {
-			      ma <- speedglm::speedlm( target ~., data=as.data.frame( dataset[, c(da, sela, sel) ] ), weights = wei )
-            tool[k] <- as.numeric( summary( ma )[[ 11 ]] )	
-			    }
-			
+          ma <- lm( target ~., data = as.data.frame( dataset[, c(da, sela, sel)] ), weights = wei, y = FALSE, model = FALSE )
+          tool[k] <- as.numeric( summary(ma)[[ 9 ]] )
+		
         } else {
             ma <- MASS::rlm( target ~., data = as.data.frame( dataset[, c(da, sela, sel)] ), maxit = 2000, weights = wei )
             r2 <- cor(target, fitted(ma) )^2
@@ -573,55 +402,45 @@ lm.fsreg_2 <- function(target, dataset, iniset = NULL, threshold = 0.05, wei = N
 
   if ( d == 0 ) {
     if ( !robust ) {
-	    if ( !heavy ) {
-        final <- lm( target ~., data = as.data.frame( iniset ), y = FALSE, model = FALSE ) 
-	    } else  final <- speedglm::speedlm( target ~., data = as.data.frame( iniset ) ) 
-	  
+      final <- lm( target ~., data = as.data.frame( iniset ), y = FALSE, model = FALSE ) 
 	  } else  final <- MASS::rlm( target ~., data = as.data.frame( iniset ), maxit = 2000, weights = wei ) 
-      info <- NULL
+    info <- NULL
     
   } else {
     
-  if ( d >= 1 ) {
-    models <- NULL
-    xx <- as.data.frame( dataset[, c(da, sela) ] )
-    if ( pa == 0 ) {
-      colnames(xx) <- paste("V", sela, sep = "") 
-    } else  colnames(xx) <- c( paste("X", da, sep = ""),  paste("V", sela, sep = "") )
-    
-    if ( d == 1 ) {
-      
+    if ( d >= 1 ) {
+      models <- NULL
       xx <- as.data.frame( dataset[, c(da, sela) ] )
       if ( pa == 0 ) {
         colnames(xx) <- paste("V", sela, sep = "") 
       } else  colnames(xx) <- c( paste("X", da, sep = ""),  paste("V", sela, sep = "") )
+    
+      if ( d == 1 ) {
+        xx <- as.data.frame( dataset[, c(da, sela) ] )
+        if ( pa == 0 ) {
+          colnames(xx) <- paste("V", sela, sep = "") 
+        } else  colnames(xx) <- c( paste("X", da, sep = ""),  paste("V", sela, sep = "") )
       
-      if ( !robust ) {
-	      if ( !heavy ) {
-          models[[ 1 ]] <- lm( target ~., data = as.data.frame( xx ), weights = wei, y = FALSE, model = FALSE )
-		    } else  models[[ 1 ]] <- speedglm::speedlm( target ~., data = as.data.frame( xx ), weights = wei )
-		
-      } else  models[[ 1 ]] <- MASS::rlm( target ~., data = as.data.frame( xx ), maxit = 2000, weights = wei )
-      
-    } else {
-      for ( i in 1:c( pa + d ) ) {
         if ( !robust ) {
-		  if ( !heavy ) {
-          models[[ i ]] <- lm( target ~., data = as.data.frame( xx[, 1:i] ), weights = wei, y = FALSE, model = FALSE )
-		  } else  models[[ i ]] <- speedglm::speedlm( target ~., data = as.data.frame( xx[, 1:i] ), weights = wei )
-		  
-        } else  models[[ i ]] <- MASS::rlm( target ~., data = data.frame( xx[, 1:i] ), maxit = 2000, weights = wei )
+          models[[ 1 ]] <- lm( target ~., data = as.data.frame( xx ), weights = wei, y = FALSE, model = FALSE )
+        } else  models[[ 1 ]] <- MASS::rlm( target ~., data = as.data.frame( xx ), maxit = 2000, weights = wei )
+      
+      } else {
+        for ( i in 1:c( pa + d ) ) {
+          if ( !robust ) {
+            models[[ i ]] <- lm( target ~., data = as.data.frame( xx[, 1:i] ), weights = wei, y = FALSE, model = FALSE )
+
+          } else  models[[ i ]] <- MASS::rlm( target ~., data = data.frame( xx[, 1:i] ), maxit = 2000, weights = wei )
+        }
       }
+    
+      final <- summary( models[[ pa + d ]] )
+      info <- info[1:d, ]
+      if ( d == 1 )  info <- matrix(info, nrow = 1)
+      info <- cbind( info, tool[ 1:d ] ) 
+      colnames(info) <- c( "variables", "log.p-value", "stat", stopping )
+      rownames(info) <- info[, 1]
     }
-    
-    final <- summary( models[[ pa + d ]] )
-    
-    info <- info[1:d, ]
-    if ( d == 1 )  info <- matrix(info, nrow = 1)
-    info <- cbind( info, tool[ 1:d ] ) 
-    colnames(info) <- c( "variables", "log.p-value", "stat", stopping )
-    rownames(info) <- info[, 1]
-  }
   
   }
   
