@@ -20,11 +20,7 @@ mmmb = function(target, dataset , max_k = 3 , threshold = 0.05 , test = "testInd
       datas <- cbind( dataset[, -varsToIterate[i] ], target)
       res <- MMPC(tar, datas, max_k = 3, threshold = threshold, test = test , user_test = user_test, hash = FALSE, robust = robust, ncores = 1, backward = FALSE) 
       poies <- sort( res@selectedVars )
-      
-      if ( !hold ) {
-        if ( d %in% poies == FALSE )   met[i] = 0;
-      }
-      
+      if ( !hold )  if ( d %in% poies == FALSE )   met[i] = 0;
       poies <- poies[ - which( poies == d ) ]
       poies[ poies >= varsToIterate[i] ] = poies[ poies >= varsToIterate[i] ] + 1
       lista[[ i ]] <- poies     
@@ -134,13 +130,9 @@ mmmb = function(target, dataset , max_k = 3 , threshold = 0.05 , test = "testInd
        
     }
 	
-  } else {
-    aa <- NULL
-  }
-  
+  } else  aa <- NULL
   
   runtime <- proc.time() - durat   
   
   list( mb = sort( c(mmpcobject@selectedVars[met], aa) ), ci_test = ci_test, runtime = runtime )
-  
 }
\ No newline at end of file
