@@ -32,13 +32,13 @@ testIndIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo =
   flag = 0;
   csIndex[which(is.na(csIndex))] = 0;
   
-  if(hash == TRUE)
+  if( hash )
   {
     csIndex2 = csIndex[which(csIndex!=0)]
     csindex2 = sort(csIndex2)
     xcs = c(xIndex,csIndex2)
     key = paste(as.character(xcs) , collapse=" ");
-    if(is.null(stat_hash[[key]]) == FALSE)
+    if( !is.null(stat_hash[[key]]) )
     {
       stat = stat_hash[[key]];
       pvalue = pvalue_hash[[key]];
@@ -51,9 +51,9 @@ testIndIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo =
   
   #if the xIndex is contained in csIndex, x does not bring any new
   #information with respect to cs
-  if(!is.na(match(xIndex,csIndex)))
+  if( !is.na(match(xIndex,csIndex)) )
   {
-    if(hash == TRUE)#update hash objects
+    if( hash )#update hash objects
     {
       stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
@@ -77,36 +77,15 @@ testIndIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo =
   x = dataset[ , xIndex];
   cs = dataset[ , csIndex];
   
-  #remove equal columns of the CS (takes a lot of time)
-  #   if(length(csIndex) > 1)
-  #   {
-  #     #remove same columns
-  #     #cs = unique(as.matrix(cs), MARGIN = 2);
-  #     #or
-  #     w = which(duplicated(cs, MARGIN = 2))
-  #     if(length(w) > 0)
-  #     {
-  #       cs = cs[,-w]
-  #     }
-  #   }
-  
-  #checking the length
-  if (length(x) == 0 || length(target) == 0)
-  {
-    message(paste("error in testIndPois : empty variable x or target"))
-    results <- list(pvalue = pvalue, stat = stat, flag = flag , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
-    return(results);
-  }
-  
   #if x = any of the cs then pvalue = 1 and flag = 1.
   #That means that the x variable does not add more information to our model due to an exact copy of this in the cs, so it is independent from the target
   if(length(cs)!=0)
   {
-    if(is.null(dim(cs)[2]) == TRUE) #cs is a vector
+    if( is.null(dim(cs)[2]) ) #cs is a vector
     {
       if(any(x != cs) == FALSE)  #if(!any(x == cs) == FALSE)
       {
-        if(hash == TRUE)#update hash objects
+        if( hash )#update hash objects
         {
           stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
           pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
@@ -119,7 +98,7 @@ testIndIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo =
       {
         if(any(x != cs[,col]) == FALSE)  #if(!any(x == cs) == FALSE)
         {
-          if(hash == TRUE)#update hash objects
+          if( hash )#update hash objects
           {
             stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
             pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
@@ -132,9 +111,9 @@ testIndIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo =
   }
   
   #if x or target is constant then there is no point to perform the test
-  if( var( as.numeric(x) ) == 0 || var(target) == 0)
+  if( vara( as.numeric(x) ) == 0 )
   {
-    if(hash == TRUE)#update hash objects
+    if( hash )#update hash objects
     {
       stat_hash[[key]] <- 0;#.set(stat_hash , key , 0)
       pvalue_hash[[key]] <- log(1);#.set(pvalue_hash , key , 1)
@@ -142,11 +121,7 @@ testIndIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo =
     results <- list(pvalue = log(1), stat = 0, flag = 1 , stat_hash=stat_hash, pvalue_hash=pvalue_hash);
     return(results);
   }
-  
-  #remove constant columns of cs
-  cs = as.matrix(cs)
-  cs = cs[,apply(cs, 2, var, na.rm=TRUE) != 0]
-  
+
   #trycatch for dealing with errors
   res <- tryCatch(
     {
@@ -189,7 +164,7 @@ testIndIGreg = function(target, dataset, xIndex, csIndex, wei = NULL, dataInfo =
         flag = 0;
       }else{
         #update hash objects
-        if(hash == TRUE)
+        if( hash )
         {
           stat_hash[[key]] <- stat;#.set(stat_hash , key , stat)
           pvalue_hash[[key]] <- pvalue;#.set(pvalue_hash , key , pvalue)
